package com.hongyegroup.cpt_parttime.ui.main

import android.graphics.Color
import android.os.Bundle
import android.view.View
import android.widget.TextView
import com.chad.library.adapter.base.listener.OnLoadMoreListener
import com.gavin.com.library.PowerfulStickyDecoration
import com.gavin.com.library.listener.PowerGroupListener
import com.guadou.cs_cptservices.base.fragment.YYBaseVDBLoadingFragment
import com.guadou.cs_cptservices.interfaces.IFragmentRefresh
import com.guadou.lib_baselib.bean.DataBindingConfig
import com.guadou.lib_baselib.ext.dp2px
import com.guadou.lib_baselib.ext.horizontal
import com.guadou.lib_baselib.ext.vertical
import com.guadou.lib_baselib.utils.KeyboardUtils
import com.guadou.lib_baselib.view.gloading.GLoadingTitleStatus
import com.guadou.lib_baselib.view.gloading.Gloading
import com.guadou.lib_baselib.view.gloading.GloadingPlaceHolderlAdapter
import com.hongyegroup.cpt_parttime.BR
import com.hongyegroup.cpt_parttime.R
import com.hongyegroup.cpt_parttime.databinding.FragmentParttimeMainBinding
import com.hongyegroup.cpt_parttime.mvvm.PartTimeHomeViewModel
import com.hongyegroup.cpt_parttime.ui.activity.PartTimeJobDetailActivity
import com.scwang.smart.refresh.layout.api.RefreshLayout
import com.scwang.smart.refresh.layout.listener.OnRefreshListener
import kotlinx.coroutines.flow.MutableStateFlow

/**
 * 兼职模块的首页Frgment
 */
class PartTimeHomeFragment : YYBaseVDBLoadingFragment<PartTimeHomeViewModel, FragmentParttimeMainBinding>(), IFragmentRefresh, OnRefreshListener,
    OnLoadMoreListener {

    private var mTopDecoration: PowerfulStickyDecoration? = null
    private val mClickProxy by lazy { ClickProxy() }

    override fun getDataBindingConfig(): DataBindingConfig {
        return DataBindingConfig(R.layout.fragment_parttime_main, BR.viewModel, mViewModel)
            .addBindingParams(BR.click, mClickProxy)
    }

    //重新生成GLoading对象-跳动动画
    override fun generateGLoading(view: View): Gloading.Holder {
        return Gloading.from(GloadingPlaceHolderlAdapter(R.layout.layout_placeholder_parttime_job))
            .wrap(view, GLoadingTitleStatus(true, true, true))
            .withRetry { onGoadingRetry() }
    }

    override fun startObserve() {
    }

    override fun init(savedInstanceState: Bundle?) {
        initRV()
        initData()
        initListener()
    }

    private fun initData() {
        mViewModel.requestJobList().observe(this) {
            mBinding.refreshLayout.finishRefresh()
            mViewModel.mAllJobAdapter.loadMoreModule.isEnableLoadMore = true

            //清楚悬停头缓存
            if (mViewModel.isNeedCleanAllData) {
                mTopDecoration?.clearCache()
            }
        }
    }

    override fun onGoadingRetry() {
        mViewModel.isNeedPlaceHolder = true
        mViewModel.mCurPage = 1
        initData()
    }

    private fun initRV() {
        //顶部的横向RV使用
        mBinding.rvNewJob.horizontal().adapter = mViewModel.mNewJobAdapter

        //悬停头的定义
        val listener: PowerGroupListener = object : PowerGroupListener {
            override fun getGroupName(position: Int): String? {
                //获取组名，用于判断是否是同一组
                return if (mViewModel.mAllJobDataes.size > position) {
                    mViewModel.mAllJobDataes[position].groupDate
                } else null
            }

            override fun getGroupView(position: Int): View {
                //获取自定定义的组View
                return if (mViewModel.mAllJobDataes.size > position) {
                    layoutInflater.inflate(R.layout.item_header_job_date, null, false).apply {
                        findViewById<TextView>(R.id.tv_head_job_date).text = mViewModel.mAllJobDataes[position].groupDate
                    }
                } else {
                    View(mActivity).apply { setBackgroundColor(Color.WHITE) }
                }
            }
        }
        mTopDecoration = PowerfulStickyDecoration.Builder
            .init(listener)
            .setGroupHeight(dp2px(40f))
            .setCacheEnable(true)
            .setHeaderCount(0) //是否有头布局->头布局的数量
            .setOnClickListener { _, _ -> //Head点击事件
            }
            .build()

        //设置悬停头和Adapter
        mBinding.rvAllJob.vertical()
            .apply {
                addItemDecoration(mTopDecoration!!)
                adapter = mViewModel.mAllJobAdapter
            }
    }

    private fun initListener() {
        //Adapter的滑动监听，监听加载更多
        mViewModel.mAllJobAdapter.loadMoreModule.isEnableLoadMore = false
        mViewModel.mAllJobAdapter.loadMoreModule.preLoadNumber = 4
        mViewModel.mAllJobAdapter.loadMoreModule.setOnLoadMoreListener(this)

        //刷新控件初始化
        mBinding.refreshLayout.setEnableNestedScroll(true)
        mBinding.refreshLayout.setEnableLoadMore(false)
        mBinding.refreshLayout.setEnableRefresh(true)
        mBinding.refreshLayout.setOnRefreshListener(this)

        //Item点击-进入详情
        mViewModel.mAllJobAdapter.setOnItemClickListener { _, view, position ->
            val item = mViewModel.mAllJobDataes[position]
            mClickProxy.gotoJobDetailPage()
        }

        //新工作的点击-进入详情
        mViewModel.mNewJobAdapter.setOnItemClickListener { _, view, position ->
            mClickProxy.gotoJobDetailPage()
        }
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        mTopDecoration?.clearCache()

        mViewModel.isNeedCleanAllData = true
        mViewModel.mAllJobAdapter.loadMoreModule.loadMoreComplete()
        mViewModel.mAllJobAdapter.loadMoreModule.isEnableLoadMore = false
        //直接调用，参数从成员变量中获取
        mViewModel.mCurPage = 1
        initData()
    }

    override fun onLoadMore() {
        mViewModel.isNeedCleanAllData = false
        mViewModel.mCurPage++
        initData()
    }

    //自动刷新
    override fun scrollTopRefresh() {
        if (mViewModel.mAllJobDataes.size > 1) {
            mBinding.rvAllJob.scrollToPosition(0)
        }
        mBinding.refreshLayout.autoRefresh()

    }

    /**
     * DataBinding事件处理
     */
    inner class ClickProxy {

        var filterIndex = MutableStateFlow(-1)

        //执行搜索
        fun doSearch() {
            KeyboardUtils.hideSoftInput(mActivity)
            scrollTopRefresh()
        }

        //搜索的删除
        fun searchDel() {
            mViewModel.mKeywordLiveData.value = ""
            doSearch()
        }

        //重置筛选的条件
        fun searchReset() {
            filterIndex.value = -1
            mViewModel.mKeywordLiveData.value = ""
            doSearch()
        }

        //跳转页面-兼职工作详情
        fun gotoJobDetailPage() {
            PartTimeJobDetailActivity.startInstance()
        }

        fun filterIndustry() {
            filterIndex.value = 0
        }

        fun filterDate() {
            filterIndex.value = 1
        }

        fun filterOption() {
            filterIndex.value = 2
        }

    }

}